# Developer's Guide

The PyTomography team highly encourages contributions from the community. We believe that such contributions will allow PyTomography to reach it's full potential as a multimodal, open-source, reconstruction framework. If you want to contribute:

1. Create an issue on the [PyTomography Github Issues page](https://github.com/qurit/PyTomography/issues). Describe what it is you intend to implement/fix. 
2. Fork the repository to your own GitHub account
3. Fix issue, and push changes to your own fork of the repository on GitHub
4. Create a pull request from your fork (whatever branch you worked on) to the development branch in the main repository